local VERSION = tonumber(("$Revision: 54644 $"):match("%d+"))

local Spyglass = Spyglass

if Spyglass.revision < VERSION then
	Spyglass.version = "r" .. VERSION
	Spyglass.revision = VERSION
	Spyglass.date = ("$Date: 2007-11-14 06:55:08 -0500 (Wed, 14 Nov 2007) $"):match("%d%d%d%d%-%d%d%-%d%d")
end

Spyglass_FuBar = AceLibrary("AceAddon-2.0"):new("AceEvent-2.0",
                                                "AceConsole-2.0",
                                                "FuBarPlugin-2.0")

local Spyglass_FuBar = Spyglass_FuBar

local Crayon = AceLibrary('Crayon-2.0')
local Tablet = AceLibrary("Tablet-2.0")
local L = AceLibrary("AceLocale-2.2"):new("Spyglass")

Spyglass_FuBar.name = 'Spyglass'
Spyglass_FuBar.version = Spyglass.version
Spyglass_FuBar.revision = Spyglass.revision
Spyglass_FuBar.date = Spyglass.date
Spyglass_FuBar.hasIcon = [[Interface\Icons\INV_Misc_Spyglass_03]]
Spyglass_FuBar.hasNoColor = true
Spyglass_FuBar.defaultMinimapPosition = 285
Spyglass_FuBar.clickableTooltip = true
Spyglass_FuBar.cannotDetachTooltip = true

function Spyglass_FuBar:OnInitialize()
    -- Method of attaching the fubar options borrowed from Bartender3
    self.db = Spyglass:AcquireDBNamespace('fubar')
    
    Spyglass.options.args.fubar_spacer = {
        order = 20,
        type = 'header',
    }
    
    Spyglass.options.args.fubar = {
        order = 21,
        type = 'group',
        name = L['Menu'],
        desc = L['Menu Options'],
        args = {},
    }
    
    AceLibrary('AceConsole-2.0'):InjectAceOptionsTable(self, Spyglass.options.args.fubar)
    self.OnMenuRequest = Spyglass.options
    
    self.classColors = {}
    for k, v in pairs(_G.RAID_CLASS_COLORS) do
        self.classColors[k] = string.format("%02x%02x%02x", v.r*255, v.g*255, v.b*255)
    end
end

function Spyglass_FuBar:OnEnable()
    self:Update()
end

function Spyglass_FuBar:OnTooltipUpdate()
    if Spyglass:IsActive() then
        local cat = Tablet:AddCategory(
            'columns', 2,
            'text', L['Last Inspected Unit']
        )
        
        local lastInspected = Spyglass.db.profile.lastInspected
        local info = Spyglass:GetUnitInfo(lastInspected)
        local name
        
        if info then
            name = Crayon:Colorize(self.classColors[info.localClass], info.name)
        else
            name = L['nobody']
        end
        
        cat:AddLine(
            'text2', name,
            'func', 'SetInspectPlayer',
            'arg1', self,
            'arg2', lastInspected
        )
        
        cat = Tablet:AddCategory(
            'columns', 3,
            'text', L['Saved Units']
        )
        
        local classColor
        
        for i, name in ipairs(Spyglass:GetCachedPlayerNames()) do
            info = Spyglass:GetUnitInfo(name)
            classColor = self.classColors[info.localClass]
            
            cat:AddLine('text', Crayon:Colorize(classColor, info.name),
                        'text2', info.level,
                        'text3', Crayon:Colorize(classColor, info.class),
                        'func', 'SetInspectPlayer', 'arg1', self, 'arg2', name)
        end
        
        Tablet:SetHint(L["|cffeda55fClick|r to toggle the inspect window."])
    else
        Tablet:SetHint(L["|cffeda55fDisabled|r"])
    end
end

function Spyglass_FuBar:SetInspectPlayer(name)
    if IsControlKeyDown() then
        Spyglass:RemoveUnitInfo(name)
        self:UpdateTooltip()
    else
        Spyglass:SetInspectPlayer(name)
    end
end

function Spyglass_FuBar:OnClick(button)
    Spyglass:ShowWindow()
end

